# -*- coding: utf-8 -*-
"""
@author: yq
@time: 2024/10/31
@desc: 一些资源初始化
"""
import sys

import matplotlib

matplotlib.use('Agg')

import matplotlib.pyplot as plt

__all__ = ['init', 'warning_ignore']


def init():
    plt.rcParams['font.sans-serif'] = ['SimHei']  # 设置支持中文的字体
    plt.rcParams['axes.unicode_minus'] = False  # 解决负号显示问题
    plt.rcParams['figure.figsize'] = (8, 8)
    plt.rcParams['figure.max_open_warning'] = 1000


def _custom_warning_filter(action, message, category, module, filename, line):
    # 如果警告消息包含“ignore this warning”，则忽略该警告
    if "matplotlib.font_manager" in str(message):
        return False
    # 否则，显示警告
    return True


def warning_ignore():
    import warnings

    # warnings.simplefilter(action="ignore", category=RuntimeWarning)
    # warnings.simplefilter(action="ignore", category=UserWarning)
    warnings.simplefilter(action="ignore", category=FutureWarning)

    warnings.filterwarnings(action="ignore", module="matplotlib")
    warnings.filterwarnings(action="ignore", module="dataframe_image")
    warnings.filterwarnings(action="ignore", module="pandas")
    warnings.filterwarnings(action="ignore", module="scorecardpy")

    if "3.6" in sys.version:
        from pandas.core.common import SettingWithCopyWarning
        warnings.simplefilter(action="ignore", category=SettingWithCopyWarning)

    if "3.10" in sys.version:
        from pandas.errors import SettingWithCopyWarning
        warnings.simplefilter(action="ignore", category=SettingWithCopyWarning)


if __name__ == "__main__":
    pass
